---
title: "Observability"
description: "Trace OpenBrowser's agent execution steps and browser sessions"
icon: "eye"
mode: "wide"
---

## Overview

OpenBrowser has a native integration with [Laminar](https://lmnr.ai) - open-source platform for tracing, evals and labeling of AI agents.
Read more about Laminar in the [Laminar docs](https://docs.lmnr.ai).

## Setup



Register on [Laminar Cloud](https://lmnr.ai) and get the key from your project settings.
Set the `LMNR_PROJECT_API_KEY` environment variable.
```bash
pip install 'lmnr[all]'
export LMNR_PROJECT_API_KEY=<your-project-api-key>
```

## Usage

Then, you simply initialize the Laminar at the top of your project and both OpenBrowser and session recordings will be automatically traced.

```python {5-8}
from openbrowser import Agent, ChatGoogle
import asyncio

from lmnr import Laminar, Instruments
# this line auto-instruments OpenBrowser and any browser you use (local or remote)
Laminar.initialize(project_api_key="...", disabled_instruments={Instruments.OPENBROWSER_SESSION})

async def main():
    agent = Agent(
        task="open google, search Laminar AI",
        llm=ChatGoogle(),
    )
    await agent.run()

asyncio.run(main())
```

## Viewing Traces

You can view traces in the Laminar UI by going to the traces tab in your project.
When you select a trace, you can see both the browser session recording and the agent execution steps.

Timeline of the browser session is synced with the agent execution steps, timeline highlights indicate the agent's current step synced with the browser session.
In the trace view, you can also see the agent's current step, the tool it's using, and the tool's input and output. Tools are highlighted in the timeline with a yellow color.

<img className="block" src="/images/laminar.png" alt="Laminar" />

## Laminar

To learn more about tracing and evaluating your browser agents, check out the [Laminar docs](https://docs.lmnr.ai).
